@@ -1,17 +1,15 @@
 # coding:utf-8
-u"""Вспомогательные функции используемые в паках."""
+u""""Вспомогательные функции используемые в паках."""
 from __future__ import absolute_import
-
 import json
 
 from django.db import models
 from django.db.models.query_utils import Q
 from m3_django_compat import get_request_params
-from six import integer_types
-from six.moves import map
-from six.moves import range
 
 from .exceptions import ApplicationLogicException
+from six.moves import map
+from six.moves import range
 
 
 def apply_sort_order(query, columns, sort_order):
@@ -238,7 +236,7 @@ def safe_delete_record(model, id=None):
 
     from m3.db import safe_delete
     assert (isinstance(model, models.Model) or issubclass(model, models.Model))
-    assert (isinstance(id, integer_types) or id is None)
+    assert (isinstance(id, int) or isinstance(id, int) or id is None)
 
     if isinstance(model, models.Model):
         obj = model
@@ -246,7 +244,7 @@ def safe_delete_record(model, id=None):
         try:
             obj = model.objects.get(pk=id)
         except model.DoesNotExist:
-            # не нашли значит уже удалили
+            #не нашли значит уже удалили
             return True
     return safe_delete(obj)
 
@@ -373,6 +371,8 @@ def extract_int(request, key):
         # из-за того, что браузер разрывает соединение,
         # в следствии этого происходит ошибка
         # IOError: request data read error
+
+        #logger.warning(str(err))
         raise
 
     if value:
@@ -388,15 +388,13 @@ def extract_int(request, key):
 
 
 def extract_int_list(request, key):
-    ''' Извлекает список целых чисел из запроса
-        ..note:: разделителем в строком значении должна быть запятая
-
+    """"
+    Извлекает список целых чисел из запроса
+      ..note:: разделителем в строком значении должна быть запятая
     :param unicode key: имя параметра
-
-    :return: список целочисленных значений из параметра с
-        заданным именем
+    :return: список целочисленных значений из параметра с заданным именем
     :rtype: list
-    '''
+    """
     value = get_request_params(request).get(key, '')
     values = list(map(int, value.split(',')))
     return values
@@ -430,25 +428,8 @@ def apply_column_filter(query, request, map):
     for key, value in map.items():
         filter_word = get_request_params(request).get(value)
         if filter_word:
-            filter_q = Q(**{key + '__icontains': filter_word})
-            cond = filter_q if not cond else (cond & filter_q)
+            filter = Q(**{key + '__icontains': filter_word})
+            cond = filter if not cond else (cond & filter)
     if cond:
         query = query.filter(cond)
     return query
-
-
-def replace_action(pack, action_attr_name, new_action):
-    """Замена указанного экшена в паке.
-
-    :param pack: Пак, в котором нужно произвести замену.
-    :type pack: m3.actions.ActionPack
-
-    :param str action_attr_name: Имя поля пака, в котором хранится ссылка на
-        экшн, подлежащий замене.
-
-    :param new_action: Новый экшн.
-    :type new_action: m3.actions.Action
-    """
-    pack.actions.remove(getattr(pack, action_attr_name))
-    setattr(pack, action_attr_name, new_action)
-    pack.actions.append(new_action)
\ No newline at end of file
